@@ -29,114 +29,13 @@ random_standard_gamma(bitgen_t* bitgen_state, double shape);
 #endif
 #define PGM_MAX_EXP 88.7228f    // maximum allowed expf() argument
 
-/*
- * Compute the complementary error function.
- *
- * This implementation uses Rational Chebyshev Approximations for as described
- * in [1]. The polynomial coefficients are obtained from [2] and some from [3].
- *
- * References
- * ----------
- * [1] Cody, W. J. Rational Chebyshev approximations for the error function.
- *     Math. Comp. 23 (1969), 631–637.
- * [2] Temme, N. (1994). A Set of Algorithms for the Incomplete Gamma Functions.
- *     Probability in the Engineering and Informational Sciences, 8(2),
- *     291-307. doi:10.1017/S0269964800003417.
- * [3] https://www.netlib.org/specfun/erf
- */
-PGM_INLINE float
-pgm_erfc(float x)
-{
-#define PGM_1_SQRTPI 0.5641895835477563f   // 1 / sqrt(pi)
-#define PGM_BIG_VAL 26.615717509251258f
-#define PGM_SMALL_VAL -6.003636680306125f
-
-    if (x < PGM_SMALL_VAL) {
-        return 2.0f;
-    }
-    else if (x < -FLT_EPSILON) {
-        return 2.0f - pgm_erfc(-x);
-    }
-    else if (x < FLT_EPSILON) {
-       return 1.0f;
-    }
-    else if (x < 0.5f) {
-        static const float
-            p0 = 3.20937758913846947e+03f,
-            p1 = 3.77485237685302021e+02f,
-            p2 = 1.13864154151050156e+02f,
-            p3 = 3.16112374387056560e+00f,
-            p4 = 1.85777706184603153e-01f,
-            q0 = 2.84423683343917062e+03f,
-            q1 = 1.28261652607737228e+03f,
-            q2 = 2.44024637934444173e+02f,
-            q3 = 2.36012909523441209e+01f;
-        float z = x * x;
-        return 1.0f - x * ((((p4 * z + p3) * z + p2) * z + p1) * z + p0) /
-                        ((((z + q3) * z + q2) * z + q1) * z + q0);
-    }
-    else if (x < 4.0f) {
-        static const float
-            p0 = 7.3738883116f,
-            p1 = 6.8650184849f,
-            p2 = 3.0317993362f,
-            p3 = 5.6316961891e-01f,
-            p4 = 4.3187787405e-05f,
-            q0 = 7.3739608908f,
-            q1 = 1.5184908190e+01f,
-            q2 = 1.2795529509e+01f,
-            q3 = 5.3542167949f;
-        return expf(-x * x) * ((((p4 * x + p3) * x + p2) * x + p1) * x + p0) /
-                              ((((x + q3) * x + q2) * x + q1) * x + q0);
-    }
-    else if (x < PGM_BIG_VAL) {
-        float z = x * x;
-        float y = expf(-z);
-
-        if (x * FLT_MIN > y * PGM_1_SQRTPI) {
-            return 0.0f;
-        }
-        static const float
-            p0 = -4.25799643553e-02f,
-            p1 = -1.96068973726e-01f,
-            p2 = -5.16882262185e-02f,
-            q0 = 1.50942070545e-01f,
-            q1 = 9.21452411694e-01f;
-        z = 1.0f / z;
-        z *= ((p2 * z + p1) * z + p0) / ((z + q1) * z + q0);
-        return y * (PGM_1_SQRTPI + z) / x;
-    }
-    else {
-        return 0.0f;
-    }
-#undef PGM_1_SQRTPI
-#undef PGM_BIG_VAL
-#undef PGM_SMALL_VAL
-}
-
 /*
  * Calculate logarithm of the gamma function of z.
  *
- * This implementation is based on an asymptotic expansion based on stirling's
- * approximation, rational approximations and a lookup table.
- *
- * - For interger values corresponding to logfactorial, we use a lookup table.
- * - Values greater than 12 use the asymptotic approximation based on stirling.
- * - For multiple intervals of values less than 12, rational approximations
- *   are used based on coefficients presented in [1].
- * - The implementation of rational approximations is based on the algorithms
- *   presented in [2].
- * - Tests show that the absolute relative error is 9.403053e-10 based on the
- *   values generated by standard library function `lgamma`.
- *
- * References
- * ----------
- *  [1] Cody, W., & Hillstrom, K. (1967). Chebyshev Approximations for the
- *      Natural Logarithm of the Gamma Function. Mathematics of Computation,
- *      21(98), 198-203. doi:10.2307/2004160.
- *  [2] Temme, N. (1994). A Set of Algorithms for the Incomplete Gamma Functions.
- *      Probability in the Engineering and Informational Sciences, 8(2),
- *      291-307. doi:10.1017/S0269964800003417.
+ * NOTE
+ * ----
+ * - For integer values corresponding to logfactorial, we use a lookup table,
+ *   otherwise we call the standard library implementation of lgamma.
  */
 PGM_INLINE double
 pgm_lgamma(double z)
@@ -214,71 +113,7 @@ pgm_lgamma(double z)
     if (z < 201. && z == (size_t)z) {
         return logfactorial[(size_t)z - 1];
     }
-    else if (z > 12.) {
-        static const double a1 = 0.08333333333333333;  // 1 / 12
-        static const double a2 = 0.002777777777777778;  // 1/360
-        static const double a3 = 0.0007936507936507937;  // 1/1260
-        double out, z2 = z * z;
-
-        out = (z - 0.5) * log(z) - z + PGM_LS2PI;
-        out += a1 / z - a2 / (z2 * z) + a3 / (z2 * z2 * z);
-        return out;
-    }
-    else if (z >= 4.) {
-        static const double p0 = -2.12159572323e+05;
-        static const double p1 = 2.30661510616e+05;
-        static const double p2 = 2.74647644705e+04;
-        static const double p3 = -4.02621119975e+04;
-        static const double p4 = -2.29660729780e+03;
-        static const double q0 = -1.16328495004e+05;
-        static const double q1 = -1.46025937511e+05;
-        static const double q2 = -2.42357409629e+04;
-        static const double q3 = -5.70691009324e+02;
-
-        return ((((p4 * z + p3) * z + p2) * z + p1) * z + p0) /
-                ((((z + q3) * z + q2) * z + q1) * z + q0);
-    }
-    else if (z > 1.5) {
-        static const double p0 = -7.83359299449e+01;
-        static const double p1 = -1.42046296688e+02;
-        static const double p2 = 1.37519416416e+02;
-        static const double p3 = 7.86994924154e+01;
-        static const double p4 = 4.16438922228;
-        static const double q0 = 4.70668766060e+01;
-        static const double q1 = 3.13399215894e+02;
-        static const double q2 = 2.63505074721e+02;
-        static const double q3 = 4.33400022514e+01;
-
-        return (z - 2.) * ((((p4 * z + p3) * z + p2) * z + p1) * z + p0) /
-                          ((((z + q3) * z + q2) * z + q1) * z + q0);
-    }
-    else {
-        static const double p0 = -2.66685511495;
-        static const double p1 = -2.44387534237e+01;
-        static const double p2 = -2.19698958928e+01;
-        static const double p3 = 1.11667541262e+01;
-        static const double p4 = 3.13060547623;
-        static const double q0 = 6.07771387771e-01;
-        static const double q1 = 1.19400905721e+01;
-        static const double q2 = 3.14690115749e+01;
-        static const double q3 = 1.52346874070e+01;
-
-        if (z >= 0.5) {
-            return (z - 1.) * ((((p4 * z + p3) * z + p2) * z + p1) * z + p0) /
-                              ((((z + q3) * z + q2) * z + q1) * z + q0);
-        }
-        else if (z > DBL_EPSILON) {
-            double x = z + 1.;
-            return z * ((((p4 * x + p3) * x + p2) * x + p1) * x + p0) /
-                        ((((x + q3) * x + q2) * x + q1) * x + q0) - log(z);
-        }
-        else if (z > DBL_MIN) {
-            return -log(z);
-        }
-        else {
-            return PGM_MAX_EXP;
-        }
-    }
+    return lgamma(z);
 }
 
 /*
@@ -474,7 +309,7 @@ upper_incomplete_gamma(float p, float x, bool normalized)
             for (r = 1.f, sum = 0.f; k < p_int + 1; ++k) {
                 sum += (r *= x / (k - 0.5f));
             }
-            return pgm_erfc(sqrt_x) + expf(-x) * one_sqrtpi * sum / sqrt_x;
+            return erfcf(sqrt_x) + expf(-x) * one_sqrtpi * sum / sqrt_x;
         }
     }
 
